@echo off
rem ===============================================================================
rem IBM Information Server Unified Governance
rem - microservice repositories database schema creation for Oracle 12c
rem
rem Copyright (C) 2009-2017 IBM Corporation. All rights reserved.
rem ===============================================================================

rem Capture parameters and set the variables:

set SYS_USER_NAME=%1%
set SYS_USER_PASSWORD=%2%
set SYS_SERVICE_NAME=%3%
set TABLESPACE_NAME=%4%
set SCHEMA_NAMES=%5%

set AS_SYSDBA=" AS SYSDBA"

set SQLPLUS_OPTIONS=%SYS_USER_NAME%/%SYS_USER_PASSWORD%@%SYS_SERVICE_NAME%%AS_SYSDBA%

rem ===============================================================================

cls
rem echo %SQLPLUS_OPTIONS%

if  "%SYS_USER_NAME%" EQU "" goto SHOW_USAGE
if  "%SYS_USER_PASSWORD%" EQU "" goto SHOW_USAGE
if  "%SYS_SERVICE_NAME%" EQU "" goto SHOW_USAGE
if  "%TABLESPACE_NAME%" EQU "" goto SHOW_USAGE
if  "%SCHEMA_NAMES%" EQU "" goto SHOW_USAGE

rem ===============================================================================
echo Checking Required files....
rem ===============================================================================

set STEP_DSC=Checking Required File.

set REQUIRED_FILE=create_ug_schema.sql
if not exist %REQUIRED_FILE% goto ERR_MISSING_FILE

rem ===============================================================================
rem Echo and get confirmation if appropriate:

echo.
echo The IBM Information Server Unified Governance service repository schemas will be created:
echo.
echo     Oracle SID : %SYS_SERVICE_NAME%
echo     Tablespace : %TABLESPACE_NAME%
echo     Schema name : %SCHEMA_NAMES%
echo.

echo Press [CTRL/C] to abort or any other key to continue
pause > nul:

rem ===============================================================================

set OUTFILE=create_ug_schemas.log
echo. >> %OUTFILE%
echo Service repository database info: >> %OUTFILE%
echo. >> %OUTFILE%
echo      Oracle SID: %SYS_SERVICE_NAME% >> %OUTFILE%
echo      Tablespace name: %TABLESPACE_NAME% >> %OUTFILE%
echo      Schema names to be created: %SCHEMA_NAMES% >> %OUTFILE%

rem ===============================================================================
rem Create Oracle Metadata Repository Schema
rem ===============================================================================

for %%a in (%SCHEMA_NAMES%) do (
  echo Creating schema: %%a...
  set SQL_LOG=create_ug_schema_sql.log
  if exist "%SQL_LOG%" (
      del "%SQL_LOG%"
  )
  sqlplus -S -L %SQLPLUS_OPTIONS% @create_ug_schema.sql %%a %TABLESPACE_NAME%
  if errorlevel 1 (
    echo.
    echo An error occurred while creating database schema %%a
    echo.
    echo See the file %SQL_LOG% for more information
    echo.
    echo CREATION FAILED >> %OUTFILE%
    echo. >> %OUTFILE%
    exit 1
  )
  echo Schema %%a created successfully
  echo.
)
goto COMPLETE_SUCCESS

rem ===============================================================================

:COMPLETE_SUCCESS
echo.

echo %0 completed

echo COMPLETED >> %OUTFILE%
echo. >> %OUTFILE%

goto GET_CONFIRMATION_EXIT

rem ===============================================================================
goto GET_CONFIRMATION_EXIT

:SHOW_USAGE
echo.
echo Usage: create_ug_db ^<OracleSystemUser^> ^<OracleSystemPassword^> ^<ServiceName^> ^<TablespaceName^> ^<SchemaNames^>
echo.
echo Sample: create_ug_db SYSTEM MANAGER DBNAME xmetaspace asset_relation
echo.
echo Parameters:
echo.
echo   ^<OracleSystemUser^>
echo     Oracle system user to login to sqlplus with to create the tablespace and
echo     user. This user must be assigned the DBA role.
echo.
echo   ^<OracleSystemPassword^>
echo     Password for the Oracle system user.
echo.
echo   ^<ServiceName^>
echo     Oracle TNS service name. This must be a working service name.
echo.
echo   ^<TableSpaceName^>
echo     Name of the tablespace to use for new schemas.
echo.
echo   ^<SchemaNames^>
echo     Names of the schemas to create. The schema names should be separated by comma.
echo.

goto EXIT_QUIET

:ERR_MISSING_FILE
echo.
echo Required file %REQUIRED_FILE% was not found.
echo.
goto EXIT_QUIET

:ERR_IN_STEP

echo.
echo An error occurred while %STEP_DSC%.
echo.
if "%STEP_LOG%"=="" goto NOLOG
echo See the file %STEP_LOG% for more information.
echo.

:ERR_EXIT
rem ===============================================================================
rem Error exit point. Always stop and prompt to insure
rem that the user sees the error message, even if we
rem are running without confirmation:

echo CREATION FAILED >> %OUTFILE%
echo. >> %OUTFILE%

echo.
echo Press any key to exit
pause > nul:
goto EXIT_QUIET
s
:EXIT
rem ===============================================================================
rem End of processing - prompt before exiting in case the
rem command file was run directly from Windows Explorer.
rem If confirmation is turned off, just exit:
EXIT /B

goto %CONFIRMATION_TARGET%_EXIT

:GET_CONFIRMATION_EXIT
echo.
echo Press any key to exit .........
pause > nul:

:SKIP_CONFIRMATION_EXIT
echo.

:EXIT_QUIET
EXIT /B

:NOLOG
goto ERR_EXIT

rem ===============================================================================
