#!/bin/sh

# ==============================================================================
# IBM Information Server Unified Governance
# - microservice repositories database schema creation for Oracle 12c
#
# Copyright (C) 2009-2017 IBM Corporation. All rights reserved.
# ==============================================================================

TRUE=0
FALSE=1

showUsage() {
  echo
  echo ' Usage: create_ug_db <OracleSystemUser> <OracleSystemPassword> <ServiceName> <TablespaceName> <SchemaNames>'
  echo
  echo Sample: create_ug_db SYSTEM MANAGER DBNAME xmetaspace asset_relation
  echo
  echo Parameters:
  echo
  echo '   <OracleSystemUser>'
  echo     Oracle system user to login to sqlplus with to create the tablespace and
  echo     user. This user must be assigned the DBA role.
  echo
  echo '   <OracleSystemPassword>'
  echo     Password for the Oracle system user.
  echo
  echo '   <ServiceName>'
  echo     Oracle TNS service name. This must be a working service name.
  echo
  echo '   <TableSpaceName>'
  echo     Name of the tablespace to use for new schemas.
  echo
  echo '   <SchemaNames>'
  echo     Names of the schemas to create. The schema names should be separated by comma.
  echo
  exit 1
}

checkRequiredFile() {
  if [ ! -f $1 ];
  then
    echo
    echo Required file $1 'was not found.'
    exit 1
  fi
}

if [ "'echo -n'" = "-n" ]; then
  n=""; c="\c"
else
  n="-n"; c=""
fi

# Capture parameters and set the variables:

SYS_USER_NAME=$1
SYS_USER_PASSWORD=$2
SYS_SERVICE_NAME=$3
TABLESPACE_NAME=$4
SCHEMA_NAMES=$5
AS_SYSDBA=" AS SYSDBA"

SQLPLUS_OPTIONS=$SYS_USER_NAME/$SYS_USER_PASSWORD@$SYS_SERVICE_NAME$AS_SYSDBA

# ==============================================================================

#echo $SQLPLUS_OPTIONS
if [ "$SYS_USER_NAME" = "" -o "$SYS_USER_PASSWORD" = "" -o "$SYS_SERVICE_NAME" = "" -o "$TABLESPACE_NAME" = "" ]
then
  showUsage
fi

# Check for required files:
echo Checking required files...
checkRequiredFile 'create_ug_schema.sql'

echo
echo The IBM Information Server Unified Governance service repository schemas will be created:
echo
echo     Oracle SID: $SYS_SERVICE_NAME
echo     Tablespace: $TABLESPACE_NAME
echo     Schema names: $SCHEMA_NAMES
echo

echo $n 'Press [CTRL/C]; to abort or [ENTER] to continue' $c; read ans
echo

# ==============================================================================

OUTFILE=create_ug_schemas.log
echo >> $OUTFILE
date >> $OUTFILE
echo Service repository database info: >> $OUTFILE
echo >> $OUTFILE
echo      Oracle SID: $SYS_SERVICE_NAME >> $OUTFILE
echo      Tablespace name: $TABLESPACE_NAME >> $OUTFILE
echo      Schema names to be created: $SCHEMA_NAMES >> $OUTFILE

for SCHEMA_NAME in $(echo $SCHEMA_NAMES | tr ',' ' '); do
  echo Creating schema: $SCHEMA_NAME...
  SQL_LOG=create_ug_schema_sql.log
  if [ -f $SQL_LOG ];
  then
    rm $SQL_LOG
  fi
  sqlplus -S -L $SQLPLUS_OPTIONS @create_ug_schema.sql $SCHEMA_NAME $TABLESPACE_NAME
  if [ "$?" = "1" ];
  then
    echo
    echo "An error occurred while creating database schema $SCHEMA_NAME"
    echo
    echo "See the file $SQL_LOG for more information"
    echo
    echo CREATION FAILED >> $OUTFILE
    echo >> $OUTFILE
    exit 1
  fi
  echo "Schema $SCHEMA_NAME created successfully"
  echo
done
# ==============================================================================

echo COMPLETED SUCCESSFULLY >> $OUTFILE
echo >> $OUTFILE
